require "numru/advanceddcl"

include NumRu::AdvancedDCL

x = [-7.5, 7.5, 7.5, -7.5, -7.5]
y = [-7.5, -7.5, 7.5, 7.5, -7.5]

Dev.open("X")

xmaxf = 26.0
ymaxf = 18.5

Frame.form(xmaxf, ymaxf)
Frame.rat(xmaxf, ymaxf)

Frame.set("lfull", true)
Frame.new

Fig.window=[-xmaxf/2.0, xmaxf/2.0, -ymaxf/2.0, ymaxf/2.0]
p Fig.window
Plot.draw(x, y)
Text.draw(0.0, 0.0, "15cm "+Text.spchar(194)+" 15cm", {"charsize"=>0.05, "charrot"=>0, "charcent"=>0, "charindex"=>3})

Dev.close 

